/**
 * Created by jmoutard on 17/05/16.
 */

'use strict';

angular.module('adf.electre')
    .controller('navigationCtrl', [
        "$scope", "$rootScope", "$q", "$location", "storeService", "defaultDashboard",
        function ($scope, $rootScope, $q, $location, storeService, defaultDashboard) {
            var nav = this;
            nav.navCollapsed = false;

            this.toggleNav = function(){ nav.navCollapsed = !nav.navCollapsed; };

            this.navClass = function(page) {
                var currentRoute = $location.path().substring(1);
                return page === currentRoute || new RegExp(page).test(currentRoute) ? 'active' : '';
            };

            this.create = function(){
                var id = '_' + Date.now();
                var q = storeService.add(id, defaultDashboard);

                $q.all([q, storeService.getAll()]).then(function(values){
                    nav.items = values[1];

                    $location.path('/board/' + id);
                    $rootScope.$broadcast('navChanged');
                });
            };
            
            storeService.getAll().then(function(data){ nav.items = data; });

            $scope.$on('navChanged', function(){
                nav.items = undefined;
                storeService.getAll().then(function(data){
                    nav.items = data;
                });
            });

            /* ROUTING ERROR */
            $rootScope.$on('$stateChangeError', function (event, toState, toParams, fromState, fromParams, error) {
                console.log(event, toState, toParams, fromState, fromParams, error);
                
            });
            $rootScope.$on('$stateChangeSuccess', function (event, toState, toParams, fromState, fromParams) {
                if (toState.name === 'logout') {
                    $rootScope.$broadcast('navChanged');
                    $location.path('/');
                }
            });
        }
    ]).controller('dashboardCtrl', [
        "$scope", "$rootScope", "$location", "$stateParams", "storeService", "data", "defaultDashboard",
        function ($scope, $rootScope, $location, $stateParams, storeService, data, defaultDashboard) {
            
            this.name = $stateParams.id || 'default';
            this.model = data || defaultDashboard;

            this.remove = function(id){
                storeService.remove(id)
                    .then(function () {
                        $rootScope.$broadcast('navChanged');
                        $location.path('/');
                    });
            };

            $scope.$on('adfDashboardChanged', function(event, name, model) {
                storeService.add(name, model).then(function () {
                    $rootScope.$broadcast('navChanged');
                });
            });
        }
    ]).controller('loginCtrl', [
        "$scope", "$location", "loginService", "$rootScope",
        function ($scope, $location, loginService, $rootScope) {
            $scope.username = "";
            $scope.password = "";
            $scope.signup = false;

            $scope.loginError =  false;
            $scope.signupError = false;

            $scope.apply = function () {
                if ($scope.signup) {
                    loginService.signup({username: $scope.username, password: $scope.password})
                        .then(function () {
                            $scope.signupError = false;
                            $rootScope.$broadcast('navChanged');
                            $location.path('/');
                        }, function () {
                            $scope.signupError = true;
                        });
                } else {
                    loginService.login({username: $scope.username, password: $scope.password})
                        .then(function () {
                            $scope.loginError = false;
                            $rootScope.$broadcast('navChanged');
                            $location.path('/');
                        }, function () {
                            $scope.loginError = true;
                        });
                }
            };
        }
    ]);